@@ -30,32 +30,33 @@
 #define LIBTASN1_ERROR_ENTRY(name) \
 	{ #name, name }
 
-struct libtasn1_error_entry {
-	const char *name;
-	int  number;
+struct libtasn1_error_entry
+{
+  const char *name;
+  int number;
 };
 typedef struct libtasn1_error_entry libtasn1_error_entry;
 
 static const libtasn1_error_entry error_algorithms[] = {
-	LIBTASN1_ERROR_ENTRY( ASN1_SUCCESS ),
-	LIBTASN1_ERROR_ENTRY( ASN1_FILE_NOT_FOUND ),
-	LIBTASN1_ERROR_ENTRY( ASN1_ELEMENT_NOT_FOUND ),
-	LIBTASN1_ERROR_ENTRY( ASN1_IDENTIFIER_NOT_FOUND ),
-	LIBTASN1_ERROR_ENTRY( ASN1_DER_ERROR ),
-	LIBTASN1_ERROR_ENTRY( ASN1_VALUE_NOT_FOUND ),
-	LIBTASN1_ERROR_ENTRY( ASN1_GENERIC_ERROR ),
-	LIBTASN1_ERROR_ENTRY( ASN1_VALUE_NOT_VALID ),
-	LIBTASN1_ERROR_ENTRY( ASN1_TAG_ERROR ),
-	LIBTASN1_ERROR_ENTRY( ASN1_TAG_IMPLICIT ),
-	LIBTASN1_ERROR_ENTRY( ASN1_ERROR_TYPE_ANY ),
-	LIBTASN1_ERROR_ENTRY( ASN1_SYNTAX_ERROR ),
-	LIBTASN1_ERROR_ENTRY( ASN1_MEM_ERROR ),
-	LIBTASN1_ERROR_ENTRY( ASN1_MEM_ALLOC_ERROR ),
-	LIBTASN1_ERROR_ENTRY( ASN1_DER_OVERFLOW ),
-	LIBTASN1_ERROR_ENTRY( ASN1_NAME_TOO_LONG ),
-	LIBTASN1_ERROR_ENTRY( ASN1_ARRAY_ERROR ),
-	LIBTASN1_ERROR_ENTRY( ASN1_ELEMENT_NOT_EMPTY ),
-	{0}
+  LIBTASN1_ERROR_ENTRY (ASN1_SUCCESS),
+  LIBTASN1_ERROR_ENTRY (ASN1_FILE_NOT_FOUND),
+  LIBTASN1_ERROR_ENTRY (ASN1_ELEMENT_NOT_FOUND),
+  LIBTASN1_ERROR_ENTRY (ASN1_IDENTIFIER_NOT_FOUND),
+  LIBTASN1_ERROR_ENTRY (ASN1_DER_ERROR),
+  LIBTASN1_ERROR_ENTRY (ASN1_VALUE_NOT_FOUND),
+  LIBTASN1_ERROR_ENTRY (ASN1_GENERIC_ERROR),
+  LIBTASN1_ERROR_ENTRY (ASN1_VALUE_NOT_VALID),
+  LIBTASN1_ERROR_ENTRY (ASN1_TAG_ERROR),
+  LIBTASN1_ERROR_ENTRY (ASN1_TAG_IMPLICIT),
+  LIBTASN1_ERROR_ENTRY (ASN1_ERROR_TYPE_ANY),
+  LIBTASN1_ERROR_ENTRY (ASN1_SYNTAX_ERROR),
+  LIBTASN1_ERROR_ENTRY (ASN1_MEM_ERROR),
+  LIBTASN1_ERROR_ENTRY (ASN1_MEM_ALLOC_ERROR),
+  LIBTASN1_ERROR_ENTRY (ASN1_DER_OVERFLOW),
+  LIBTASN1_ERROR_ENTRY (ASN1_NAME_TOO_LONG),
+  LIBTASN1_ERROR_ENTRY (ASN1_ARRAY_ERROR),
+  LIBTASN1_ERROR_ENTRY (ASN1_ELEMENT_NOT_EMPTY),
+  {0}
 };
 
 #define LIBTASN1_ERROR_LOOP(b) \
@@ -74,16 +75,16 @@ static const libtasn1_error_entry error_algorithms[] = {
   * This function is like perror(). The only difference is that it
   * accepts an error returned by a libtasn1 function.
   **/
-void libtasn1_perror(asn1_retCode error)
+void
+libtasn1_perror (asn1_retCode error)
 {
-	const char *ret = NULL;
+  const char *ret = NULL;
 
-	/* avoid prefix */
-	LIBTASN1_ERROR_ALG_LOOP(ret =
-			      p->name + sizeof("ASN1_") - 1);
+  /* avoid prefix */
+  LIBTASN1_ERROR_ALG_LOOP (ret = p->name + sizeof ("ASN1_") - 1);
+
+  _libtasn1_log ("LIBTASN1 ERROR: %s\n", ret);
 
-	_libtasn1_log( "LIBTASN1 ERROR: %s\n", ret);
-	
 }
 
 
@@ -97,34 +98,38 @@ void libtasn1_perror(asn1_retCode error)
   * Returns: Pointer to static zero-terminated string describing error
   *   code.
   **/
-const char* libtasn1_strerror(asn1_retCode error)
+const char *
+libtasn1_strerror (asn1_retCode error)
 {
-	const char *ret = NULL;
+  const char *ret = NULL;
 
-	/* avoid prefix */
-	LIBTASN1_ERROR_ALG_LOOP(ret =
-			      p->name + sizeof("ASN1_") - 1);
+  /* avoid prefix */
+  LIBTASN1_ERROR_ALG_LOOP (ret = p->name + sizeof ("ASN1_") - 1);
 
-	return ret;
+  return ret;
 }
 
 /* this function will output a message.
  */
 #ifdef LIBTASN1_DEBUG
-void _libtasn1_log( const char *fmt, ...) {
- va_list args;
- char str[MAX_LOG_SIZE];
+void
+_libtasn1_log (const char *fmt, ...)
+{
+  va_list args;
+  char str[MAX_LOG_SIZE];
 
- va_start(args,fmt);
- vsprintf( str,fmt,args); /* Flawfinder: ignore */
- va_end(args);
+  va_start (args, fmt);
+  vsprintf (str, fmt, args);	/* Flawfinder: ignore */
+  va_end (args);
 
- fprintf(stderr, str);
+  fprintf (stderr, str);
 
- return;
+  return;
 }
 #else /* not DEBUG */
-void _libtasn1_log( const char *fmt, ...) {
+void
+_libtasn1_log (const char *fmt, ...)
+{
   return;
 }
 #endif /* DEBUG */
